# frozen_string_literal: true

#
# This function checks if domain exists in the specified location.
#
#
# See the file "LICENSE" for the full license governing this code.
#
Puppet::Functions.create_function(:'wls_install::domain_exists') do
  dispatch :domain_exists do
    param 'String', :domain_dir
    return_type 'Boolean'
  end

  def domain_exists(domain_dir)
    scope = closure_scope
    fact = scope['wls_install_domains']
    if fact.keys.empty?
      call_function('wls_install::log', 'domain_exists no domains found, return false')
      return false
    else
      fact.each_key do |domain|
        domain_path = fact[domain]['path']
        if domain_path == domain_dir
          call_function('wls_install::log', "domain_exists domain found '#{domain_path}' is '#{domain_dir}', return true")
          return true
        end
      end
    end
    call_function('wls_install::log', 'domain_exists domain not found, return false')
    false
  end
end
