# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
module Puppet
  Type.newtype(:wls_directory_structure) do
    def self.module_name
      'wls_install'
    end
    desc 'add all the directories needed by the oracle weblogic installation'

    newparam(:name) do
      desc <<-DESC
        The title.
      DESC
      isnamevar
    end

    newproperty(:ensure) do
      desc 'Whether to do something.'

      newvalue(:present) do
        provider.configure
      end

      def retrieve
        oracle_base     = resource[:oracle_base_dir]
        ora_inventory   = resource[:ora_inventory_dir]
        download_folder = resource[:download_dir]

        if File.exist?(oracle_base) && File.exist?(ora_inventory) && File.exist?(download_folder)
          :present
        else
          :absent
        end
      end
    end

    newparam(:oracle_base_dir) do
      desc <<-DESC
        The oracle base folder.
      DESC
      validate do |value|
        fail ArgumentError, 'oracle_base_dir cannot be empty' if value.nil?
      end
    end

    newparam(:ora_inventory_dir) do
      desc <<-DESC
        The oracle inventory folder.
      DESC
      validate do |value|
        fail ArgumentError, 'ora_inventory_dir cannot be empty' if value.nil?
      end
    end

    newparam(:wls_domains_dir) do
      desc <<-DESC
        The oracle weblogic domains folder.
      DESC
    end

    newparam(:wls_apps_dir) do
      desc <<-DESC
        The oracle weblogic apps folder.
      DESC
    end

    newparam(:download_dir) do
      desc <<-DESC
        The download folder.
      DESC
      validate do |value|
        fail ArgumentError, 'download_dir cannot be empty' if value.nil?
      end
    end

    newparam(:os_user) do
      desc <<-DESC
        The weblogic operating system user.
      DESC

      defaultto 'oracle'
    end

    newparam(:os_group) do
      desc <<-DESC
        The weblogic operating system group.
      DESC

      defaultto 'dba'
    end
  end
end
