#
# wls_install::software
#
# @summary 
# This class allows you install the WebLogic software on your system. Here is an example on how you could use this:```class{'ora_install::software':  version              => 1221,                       # 1036|1211|1212|1213|1221  filename             => 'fmw_12.2.1.0.0_wls.jar',   #   jdk_home_dir         => '/usr/java/jdk1.8.0_45',  oracle_base_home_dir => "/opt/oracle",  middleware_home_dir  => "/opt/oracle/middleware12c",  weblogic_home_dir    => "/opt/oracle/middleware12c/wlserver",  os_user              => "oracle",  os_group             => "dba",  download_dir         => "/data/install",  source               => "/vagrant",                 # puppet:///modules/orawls/ | /mnt |  logoutput           => true,}```
#
# @param [Wls_install::Versions] version
#    The version that is installed in the used Oracle home.
#    Puppet uses this value to decide on version specific actions.
#
# @param [String[1]] filename
#    The source file to use.
#
# @param [Stdlib::Absolutepath] oracle_base_home_dir
#    A directory to use as Oracle base directory.
#
# @param [Stdlib::Absolutepath] middleware_home_dir
#    Middleware home directory.
#
# @param [Optional[Stdlib::Absolutepath]] weblogic_home_dir
#    Directory to use as WebLogic home.
#
# @param [Optional[Stdlib::Absolutepath]] wls_domains_dir
#    The root directory where all domain directories reside in.
#
# @param [Optional[Stdlib::Absolutepath]] wls_apps_dir
#    The root directory where all aplication directories reside in.
#
# @param [Boolean] fmw_infra
#    Determine if you want to install Fusion Middleware infra.
#
# @param [Stdlib::Absolutepath] jdk_home_dir
#    The homdirectory for the Java evelopment Kit.
#
# @param [String[1]] os_user
#    The os user used to install and run WebLogic.
#
# @param [String[1]] os_group
#    The os group used to install and run WebLogic.
#
# @param [Stdlib::Absolutepath] download_dir
#    The directory where the Puppet software puts all downloaded files.
#    Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.
#    The default value is: `/install`
#
# @param [String[1]] source
#    Source for the operation.
#
# @param [Optional[String]] java_parameters
#    The (extra) parameters to pass when calling java.
#
# @param [Stdlib::Absolutepath] temp_directory
#    Directory to use for temporary files.
#
# @param [Variant[Boolean, Enum['on_failure']]] logoutput
#    log the outputs of Puppet exec or not.
#    When you specify `true` Puppet will log all output of `exec` types.
#    Valid values are:
#    - `true`
#    - `false`
#    - `on_failure`
#
#
# See the file "LICENSE" for the full license governing this code.
#
class wls_install::software (
  Wls_install::Versions          $version              = 1111,
  String[1]                      $filename             = undef,
  Stdlib::Absolutepath           $oracle_base_home_dir = undef,
  Stdlib::Absolutepath           $middleware_home_dir  = undef,
  Optional[Stdlib::Absolutepath] $weblogic_home_dir    = undef,
  Optional[Stdlib::Absolutepath] $wls_domains_dir      = undef,
  Optional[Stdlib::Absolutepath] $wls_apps_dir         = undef,
  Boolean                        $fmw_infra            = false,
  Stdlib::Absolutepath           $jdk_home_dir         = undef,
  String[1]                      $os_user              = undef,
  String[1]                      $os_group             = undef,
  Stdlib::Absolutepath           $download_dir         = undef,
  String[1]                      $source               = undef,
  Optional[Stdlib::Absolutepath] $oracle_inventory_dir = undef,
  Optional[String]               $java_parameters      = '',
  Stdlib::Absolutepath           $temp_directory       = '/tmp',
  Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]                              $logoutput            = lookup({name => 'logoutput', default_value => 'on_failure'}),
) {

  easy_type::debug_evaluation() # Show local variable on extended debug

  wls_install::software_version{ 'base':
    version              => $version,
    filename             => $filename,
    oracle_base_home_dir => $oracle_base_home_dir,
    middleware_home_dir  => $middleware_home_dir,
    weblogic_home_dir    => $weblogic_home_dir,
    wls_domains_dir      => $wls_domains_dir,
    wls_apps_dir         => $wls_apps_dir,
    fmw_infra            => $fmw_infra,
    jdk_home_dir         => $jdk_home_dir,
    os_user              => $os_user,
    os_group             => $os_group,
    download_dir         => $download_dir,
    source               => $source,
    oracle_inventory_dir => $oracle_inventory_dir,
    java_parameters      => $java_parameters,
    logoutput            => $logoutput,
    temp_directory       => $temp_directory,
  }
}
